==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/SlowAvailableExpressionsAnalysis.h <==
// class soot.jimple.toolkits.scalar.SlowAvailableExpressionsAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5cb3057bc1d5168b soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis_H_
#define _JC_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *);
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *);
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods	soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs {
	struct _jc_object	*unitToGenerateSet;
	struct _jc_object	*unitToPreserveSet;
	struct _jc_object	*rhsToContainingStmt;
	struct _jc_java_util_HashMap$object	*valueToEquivValue;
	struct _jc_object	*emptySet;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs {
    _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs	soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs	soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object {
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/SlowAvailableExpressionsAnalysis.h <==
// class soot.jimple.toolkits.scalar.SlowAvailableExpressionsAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5cb3057bc1d5168b soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis_H_
#define _JC_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vmethods	soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs {
	struct _jc_object	*unitToGenerateSet;
	struct _jc_object	*unitToPreserveSet;
	struct _jc_object	*rhsToContainingStmt;
	struct _jc_java_util_HashMap$object	*valueToEquivValue;
	struct _jc_object	*emptySet;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs {
    _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_refs	soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$sub_nonrefs	soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$object {
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$vtype _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_SlowAvailableExpressionsAnalysis_H_ */
